==> apache-nuttx-9.1.1-incubating.tar.gz: nuttx/arch/arm/include/cxd56xx/timer.h <==
/****************************************************************************
 * arch/arm/include/cxd56xx/timer.h
 *
 *   Copyright 2018 Sony Semiconductor Solutions Corporation
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name of Sony Semiconductor Solutions Corporation nor
 *    the names of its contributors may be used to endorse or promote
 *    products derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

#ifndef __ARCH_ARM_INCLUDE_CXD56XX_TIMER_H
#define __ARCH_ARM_INCLUDE_CXD56XX_TIMER_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/timers/timer.h>

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

/* Set callback handler
 *
 * param A pointer to struct timer_sethandler_s
 * return ioctl return value provides success/failure indication
 */

#define TCIOC_SETHANDLER _TCIOC(0x0020)

/****************************************************************************
 * Public Types
 ****************************************************************************/

/* This is the type of the argument passed to the TCIOC_SETHANDLER ioctl */

struct timer_sethandler_s
{
  FAR void    *arg;            /* An argument */
  CODE tccb_t handler;         /* The timer interrupt handler */
};

#endif /* __ARCH_ARM_INCLUDE_CXD56XX_TIMER_H */

==> apache-nuttx-10.2.0-incubating.tar.gz: nuttx/arch/arm/include/cxd56xx/timer.h <==
/****************************************************************************
 * arch/arm/include/cxd56xx/timer.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __ARCH_ARM_INCLUDE_CXD56XX_TIMER_H
#define __ARCH_ARM_INCLUDE_CXD56XX_TIMER_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/timers/timer.h>

/****************************************************************************
 * Pre-processor Prototypes
 ****************************************************************************/

/* Set callback handler
 *
 * param A pointer to struct timer_sethandler_s
 * return ioctl return value provides success/failure indication
 */

#define TCIOC_SETHANDLER _TCIOC(0x0020)

/****************************************************************************
 * Public Types
 ****************************************************************************/

/* This is the type of the argument passed to the TCIOC_SETHANDLER ioctl */

struct timer_sethandler_s
{
  FAR void    *arg;            /* An argument */
  CODE tccb_t handler;         /* The timer interrupt handler */
};

#endif /* __ARCH_ARM_INCLUDE_CXD56XX_TIMER_H */
